import { Vector2 } from 'three';
import { BlendFunction, Effect } from 'postprocessing';
/**
 * BarrelBlurEffect - A custom effect for applying a barrel distortion
 * with chromatic aberration blur.
 */
export declare class BarrelBlurEffect extends Effect {
    /**
     * Creates a new BarrelBlurEffect instance.
     *
     * @param {object} [options] - Configuration options for the effect.
     * @param {BlendFunction} [options.blendFunction] - Blend mode.
     * @param {number} [options.amount] - Intensity of the barrel distortion (0 to 1).
     * @param {Vector2} [options.offset] - Offset of the barrel distortion center (0 to 1 for both x and y). This allows you to change the position of the distortion effect.
     *
     */
    constructor({ blendFunction, amount, offset }?: {
        blendFunction?: BlendFunction | undefined;
        amount?: number | undefined;
        offset?: Vector2 | undefined;
    });
    /**
     * The amount.
     *
     * @type {number}
     */
    get amount(): any;
    set amount(value: any);
    /**
     * The offset.
     *
     * @type {Vector2}
     */
    get offset(): any;
    set offset(value: any);
}
